# Generated by Django 3.2.7 on 2022-10-11 10:08

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='AdminApps',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('app_name', models.CharField(max_length=50, unique=True)),
                ('app_url', models.CharField(max_length=250)),
                ('redirect_url', models.CharField(max_length=250)),
                ('app_order', models.IntegerField()),
            ],
            options={
                'verbose_name': 'Admin App',
                'verbose_name_plural': 'Admin Apps',
            },
        ),
    ]
