# Generated by Django 3.2.7 on 2022-10-11 10:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_microservice_admin', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='adminapps',
            name='app_order',
            field=models.IntegerField(default=0),
        ),
        migrations.AlterField(
            model_name='adminapps',
            name='app_url',
            field=models.CharField(blank=True, max_length=250, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name='adminapps',
            name='redirect_url',
            field=models.CharField(blank=True, max_length=250, null=True, unique=True),
        ),
    ]
